@@ -39,16 +39,20 @@ namespace Shopper
 	List::List() :
 		name(tr("Sainsburys")),
 		state(MAKING_LIST),
-		active_category(0)
+		active_category(0),
+		invalid(false)
 	{
 		// No items, no categories
 		DEBUG("\n\n\nMAKING NEW LIST\n\n\n");
 	}
-	List::List(QString dump)
+	List::List(QString dump) :
+		invalid(false)
 	{
 		DEBUG("\n\n\nMAKING NEW LIST FROM STRING\n\n\n");
 		ListParser parse(this);
-		parse.from_string(dump);
+		if (! parse.from_string(dump) ) {
+			this->invalid = true;
+		}
 	}   // initiate from a dump
 
 	List::~List()
@@ -71,7 +75,13 @@ namespace Shopper
 		QString qxml = xml.readAll();
 		DEBUG("read from : " <<filename <<"\n"<<qxml);
 		// Create new list and return it
-		return new Shopper::List(qxml); // FIXME: may not succeed.
+		Shopper::List *l;
+		l = new Shopper::List(qxml);
+		if (l->invalid) {
+			delete l;
+			l = NULL;
+		}
+		return l;
 	}
 
 	void List::to_file(QString filename)
@@ -132,6 +142,11 @@ namespace Shopper
 		delete &cat;
 	}
 
+	int List::size()
+	{
+		return categories.size();
+	}
+
 	// accessors
 	QString List::get_name() const {return name;}
 	void List::set_name(QString)
@@ -222,7 +237,11 @@ namespace Shopper
 	void List::make_category_active(Category &c)
 	{
 		if (active_category != &c) {
+			disconnect(&c, SIGNAL(changed()),
+					this, SIGNAL(active_category_changed()));
 			active_category = &c;
+			connect(&c, SIGNAL(changed()),
+					this, SIGNAL(active_category_changed()));
 // If using a set for multiple active categories
 //		active_categories.insert(c);
 			emit active_category_changed();
@@ -233,6 +252,8 @@ namespace Shopper
 		// Comment out if you want to use the commented out code below
 		Q_UNUSED(c)
 		if (active_category != 0) {
+			disconnect(active_category, SIGNAL(changed()),
+					   this, SIGNAL(active_category_changed()));
 			active_category = 0;
 // If using a set for multiple active categories
 //		active_categories.erase(c);
@@ -242,6 +263,8 @@ namespace Shopper
 	void List::no_category_active()
 	{
 		if (active_category != 0) {
+			disconnect(active_category, SIGNAL(changed()),
+					   this, SIGNAL(active_category_changed()));
 			active_category = 0;
 			emit active_category_changed();
 		}
