@@ -33,7 +33,7 @@ int main(int argc, char *argv[])
 	// gtk uses:   /apps/maemo/shopper/list_filename
 //	Shopper::List* list;
 
-	QString filename = "~/shopping.xml";
+	QString filename = QLatin1String("~/shopping.xml");
     MainWindow mainWin(filename);
 //	mainWin.setAttribute(Qt::WA_Maemo5AutoOrientation, true);
     mainWin.show();
