@@ -25,7 +25,7 @@
 //#include "config.h"
 
 // Default location of shopping lists
-#define HOME_DIR "/home/user/"
+#define HOME_DIR "/home/user/MyDocs/"
 #define DEFAULT_LIST "ShoppingList.xml"
 
 #include <iostream>
